-- This example uses the default box2d (love.physics) plugin!!

local sti = require "sti"

function love.load()
    -- Grab window size
    windowWidth  = love.graphics.getWidth()
    windowHeight = love.graphics.getHeight()

    -- Set world meter size (in pixels)
    love.physics.setMeter(70)

    -- Load a map exported to Lua from Tiled
    map = sti("map.lua", { "box2d" })

    -- Prepare physics world with horizontal and vertical gravity
    world = love.physics.newWorld(0, 5500)

    -- Prepare collision objects
    map:box2d_init(world)
    world:setCallbacks(beginContact)

    -- Create a Custom Layer
    map:addCustomLayer("Sprite Layer", 2)

    -- Add data to Custom Layer
    local spriteLayer = map.layers["Sprite Layer"]
    spriteLayer.sprites = {
        door = {
            image = love.graphics.newImage("door_closed.png"),
            x = love.graphics.getWidth() - 70,
            y = 100
        },

        key = {
            image = love.graphics.newImage("key.png"),
            x = 420,
            y = 140
        },

        player = {
            image = love.graphics.newImage("player.png"),
            x = 0,
            y = 210 - 97,
            xvel = 0,
            yvel = 0
        }
    }

    player = spriteLayer.sprites.player
    player.body = love.physics.newBody(world, player.x + player.image:getWidth()/2, player.y + player.image:getWidth()/2 + 30, 'dynamic')
    player.body:setLinearDamping(10)
    player.body:setFixedRotation(true)

    player.shape = love.physics.newRectangleShape(68, 97)
    player.fixture = love.physics.newFixture(player.body, player.shape)

    -- Update callback for Custom Layer
    function spriteLayer:update(dt)

    end

    -- Draw callback for Custom Layer
    function spriteLayer:draw()
        for _, sprite in pairs(self.sprites) do
            local x = math.floor(sprite.x)
            local y = math.floor(sprite.y)
            local r = sprite.r
            love.graphics.draw(sprite.image, x, y, r)
        end
    end
end

function love.update(dt)
    world:update(dt)
    local down = love.keyboard.isDown

    local x, y= 0, 0
    local jumpHeight = -1000

    --if down("s") or down("down")     then y = y + 4000 end
    if down("a", "left")     then x = x - 6000 end
    if down("d", "right")    then x = x + 6000 end
    player.body:applyForce(x, y)
    player.x = player.body:getX() - player.image:getWidth() / 2
    player.y = player.body:getY() - player.image:getHeight()/2


    
    map:update(dt)
    world:update(dt)
end

function love.draw()
    -- Translation would normally be based on a player's x/y
    local translateX = 0
    local translateY = 0

    -- Draw the map and all objects within
    map:draw()

    -- Draw Collision Map (useful for debugging)
    love.graphics.setColor(255, 0, 0, 255)
    map:box2d_draw()

    -- Draw character lines
    love.graphics.polygon("line", player.body:getWorldPoints(player.shape:getPoints()))
--    love.graphics.pop()

    -- Reset color
    love.graphics.setColor(255, 255, 255, 255)
end